# Generated by roxygen2: do not edit by hand

S3method(plot,nonlinear_aggte)
S3method(plot,nonlinear_attgt)
S3method(print,binary_did_dr)
S3method(print,binary_did_logit)
S3method(print,binary_did_probit)
S3method(print,count_did_poisson)
S3method(print,nonlinear_aggte)
S3method(print,nonlinear_attgt)
S3method(print,nonlinear_pretest)
S3method(print,odds_ratio_did)
S3method(summary,nonlinear_aggte)
S3method(summary,nonlinear_attgt)
export(binary_did_dr)
export(binary_did_logit)
export(binary_did_probit)
export(count_did_poisson)
export(nonlinear_aggte)
export(nonlinear_attgt)
export(nonlinear_bounds)
export(nonlinear_pretest)
export(odds_ratio_did)
export(sim_binary_panel)
export(sim_binary_rcs)
export(sim_count_panel)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_errorbar)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
